import psutil as _psutil
from functools import lru_cache

@lru_cache
def get_ram():
    virtual_mem = _psutil.virtual_memory()    
    return virtual_mem.total

def get_available_ram():
    virtual_mem = _psutil.virtual_memory()    
    return virtual_mem.available

def get_used_ram():
    virtual_mem = _psutil.virtual_memory()    
    return virtual_mem.used

@lru_cache
def get_swap_ram():
    swap_mem = _psutil.swap_memory()
    return swap_mem.total

def get_used_swap_ram():
    swap_mem = _psutil.swap_memory()
    return swap_mem.used



import psutil as _psutil
from functools import lru_cache

@lru_cache
def get_cpu_cores(): 
    """
    Returns the number of cpu cores in your computer.
    """
    return _psutil.cpu_count(logical=False)
@lru_cache
def get_virtual_cpu_cores(): 
    """
    Returns the number of virtual cpu cores in your computer.
    Virtual cores are used to make a cpu more like a GPU to increase its speed.
    """
    return _psutil.cpu_count(logical=True)

# optimize it by storing it in cache cuz its not like the user is changing the cpu while its running
@lru_cache
def get_max_cpu_speed():
    cpu_freq = _psutil.cpu_freq()
    return cpu_freq.max

@lru_cache
def get_min_cpu_speed():
    cpu_freq = _psutil.cpu_freq()
    return cpu_freq.min

def get_cpu_usage():
    cpu_freq = _psutil.cpu_freq()
    return cpu_freq.current



# Functions
cpu  = ['get_cpu_cores', 'get_virtual_cpu_cores', 'get_max_cpu_speed', 'get_min_cpu_speed', 'get_cpu_usage']
ram  = ['get_ram', 'get_available_ram', 'get_used_ram', 
        'get_swap_ram', 'get_used_swap_ram']
disk = ['get_disk_partitions', 'get_file_system_type', 'get_mount_point']

__all__ = cpu + ram + disk

from cpu  import *
from ram  import *
from disk import *

_ = get_cpu_cores, get_virtual_cpu_cores, get_max_cpu_speed, get_min_cpu_speed, get_cpu_usage, \
    get_ram, get_available_ram, get_used_ram, \
    get_swap_ram, get_used_swap_ram, \
    get_disk_partitions, get_file_system_type, get_mount_point



import psutil as _psutil

def get_disk_partitions():
    partitions = _psutil.disk_partitions()
    return [partition.device for partition in partitions]

def get_file_system_type(partition_name):
    partitions = _psutil.disk_partitions()
    partition_dict = {partition.device : partition.fstype for partition in partitions}
    return partition_dict[partition_name]

def get_mount_point(partition_name):
    partitions = _psutil.disk_partitions()
    partition_dict = {partition.device : partition.mountpoint for partition in partitions}
    return partition_dict[partition_name]



from setuptools import setup, find_packages
import codecs
import os

here = os.path.abspath(os.path.dirname(__file__))

with codecs.open(os.path.join(here, "README.md"), encoding="utf-8") as fh:
    long_description = "\n" + fh.read()

VERSION = '1.0.1'
DESCRIPTION = 'Get information about your system.'
LONG_DESCRIPTION = 'This package allows you to get information about your system.'

# Setting up
setup(
    name="systore",
    version=VERSION,
    author="Schkimansky",
    author_email="<ahmadchawla1432@gmail.com>",
    description=DESCRIPTION,
    long_description_content_type="text/markdown",
    long_description=long_description,
    packages=find_packages(),
    install_requires=['psutil'],
    keywords=['python', 'system', 'information', 'get information', 'get', 'get info', 'system info', 'get sys info' 'get system info'],
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Intended Audience :: Developers",
        "Programming Language :: Python :: 3",
        "Operating System :: Unix",
        "Operating System :: MacOS :: MacOS X",
        "Operating System :: Microsoft :: Windows",
    ]
)
